..
    This file is part of Invenio.
    Copyright (C) 2015-2022 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Installation
============

Invenio-Base is on PyPI so all you need is:

.. code-block:: console

   $ pip install invenio-base

You can install a development version and run tests using:

.. code-block:: console

    $ cd invenio-base
    $ pip install -e ".[tests]"
    $ ./run-tests.sh
